﻿Type=Class
Version=4.3
ModulesStructureVersion=1
B4i=true
@EndOfDesignText@
'ValiDialog class - implements a number of different kinds of dialog (message and input) with optional validation on the input dialogs

#Event: Dialog_Result (Result as Int)

Sub Class_Globals
	Public const DIALOGTYPE_TOAST As Int = 0
	
	Private const ClassName As String = "ValiDialog"
	
	Private const DIALOGTYPE_MAX As Int = DIALOGTYPE_TOAST
	Private const DIALOGTYPES() As String = Array As String( _
		"Toast")
	Private myDialogType As Int
	
	Private myMessage As CSBuilder
	
End Sub

#Region Setup/ShowToast/Close
'Set callback info, DialogType and initial Message value (CSBuilder or String)
Public Sub Initialize(DialogType As Int, Message As Object) As ValiDialog
	If DialogType < 0 Or DialogType > DIALOGTYPE_MAX Then RaiseException($"${ClassName}.Initialize"$, $"Invalid DialogType: ${DialogType}"$)
	myDialogType = DialogType
	setMessage(Message)
	Return Me
End Sub

'Shows a message using ToastMessageShow (Android) or iHUD (IOS)
public Sub ShowToast(LongDuration As Boolean)
	'Check ValiDialog type
	Select myDialogType
	Case DIALOGTYPE_TOAST
	Case Else
		RaiseException($"${ClassName}.ShowToast"$, $"Should only be called for 'Toast' DialogType (Dialog Type used was ${DIALOGTYPES(myDialogType)})"$)
	End Select
	'Show the message
#If B4A
	ToastMessageShow(myMessage, LongDuration)
#Else If B4i
	Dim Toast As HUD
	Toast.ToastMessageShow(myMessage.ToString, LongDuration)
#End If
End Sub
#End Region

#Region Properties
'Property: DialogType - get Dialog Type
public Sub getDialogType As Int
	Return myDialogType
End Sub

'Property: Message - gets/set Message as a String or CS Builder
public Sub getMessage As CSBuilder
	Return myMessage 'Always return a CSBuilder - other subs will use as-is or convert to String if needed
End Sub
public Sub setMessage(NewValue As Object)
	andMessage(NewValue)
End Sub
public Sub andMessage(NewValue As Object) As ValiDialog
	If NewValue Is String Then
		myMessage.Initialize.Append(NewValue).PopAll
	Else If NewValue Is CSBuilder Then
		myMessage = NewValue
	Else
		RaiseException($"${ClassName}.Message"$, $"Expecting String or CSBuilder, received ${GetType(NewValue)}."$)
	End If
	Return Me
End Sub

#Region Utility
'Logs exception information then raises an exception to abort execution
Private Sub RaiseException(Location As String, Description As String)
	Log($"*** ERROR *** Location='${Location}' Description='${Description}'"$)
	If LastException.IsInitialized Then
#If B4i
		Log($"Last Exception: Error ${LastException.Code} '${LastException.Message}' in ${LastException.Domain}"$)
#Else
		Log($"Last Exception: '${LastException.Message}'"$)
#End If
	End If
	Dim i As Int = "A" 'ignore - Causes an exception whatever the platform
End Sub
#End Region